import { renderless, api } from '@opentinyvue/vue-renderless/calendar/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Tooltip from '@opentinyvue/vue-tooltip';
import Popover from '@opentinyvue/vue-popover';
import Button from '@opentinyvue/vue-button';
import { iconChevronUp, iconChevronDown } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    Tooltip,
    Popover,
    Button,
    IconChevronUp: iconChevronUp(),
    IconChevronDown: iconChevronDown()
  },
  props: [].concat(props, ["mode", "year", "month", "events", "showSelected"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-calendar"
  }, [_c("div", {
    staticClass: "tiny-calendar__header"
  }, [_vm.showSelected && _vm.state.selectedTip ? _c("div", {
    staticClass: "tiny-calendar__selected"
  }, [_vm._v(" " + _vm._s(_vm.state.selectedTip) + " ")]) : _vm._e(), _vm._t("tool", function() {
    return [_c("ul", {
      staticClass: "tiny-calendar__tool"
    }, [_c("li", [_c("Popover", {
      attrs: {
        "placement": "bottom-start",
        "trigger": "click",
        "transition": "tiny-transition-zoom-in-top",
        "popper-class": "tiny-calendar is-popover",
        "visible-arrow": false
      },
      scopedSlots: _vm._u([{
        key: "reference",
        fn: function fn() {
          return [_c("div", {
            staticClass: "tiny-calendar__input"
          }, [_c("input", {
            attrs: {
              "type": "text",
              "readonly": ""
            },
            domProps: {
              "value": _vm.state.activeYear + _vm.t("ui.datepicker.year")
            }
          }), _c("div", {
            staticClass: "tiny-calendar__input-btn"
          }, [_c(_vm.state.showYear ? "icon-chevron-up" : "icon-chevron-down", {
            tag: "component",
            staticClass: "tiny-svg-size"
          })], 1)])];
        },
        proxy: true
      }, {
        key: "default",
        fn: function fn() {
          return [_c("div", {
            staticClass: "tiny-calendar__selector"
          }, [_c("ul", {
            staticClass: "tiny-calendar__poplist"
          }, _vm._l(_vm.state.dropdownYear, function(year) {
            return _c("li", {
              key: year,
              class: ["tiny-calendar__list-item", {
                "is-selected": _vm.state.activeYear === year
              }],
              attrs: {
                "title": year + _vm.t("ui.datepicker.year")
              },
              on: {
                "click": function click() {
                  _vm.state.activeYear = year;
                  _vm.state.showYear = false;
                }
              }
            }, [_vm._v(" " + _vm._s(year + _vm.t("ui.datepicker.year")) + " ")]);
          }), 0)])];
        },
        proxy: true
      }]),
      model: {
        value: _vm.state.showYear,
        callback: function callback($$v) {
          _vm.$set(_vm.state, "showYear", $$v);
        },
        expression: "state.showYear"
      }
    })], 1), _c("li", {
      directives: [{
        name: "show",
        rawName: "v-show",
        value: _vm.state.displayMode === "month",
        expression: "state.displayMode === 'month'"
      }]
    }, [_c("Popover", {
      attrs: {
        "transition": "tiny-transition-zoom-in-top",
        "placement": "bottom-start",
        "trigger": "click",
        "popper-class": "tiny-calendar is-popover",
        "visible-arrow": false
      },
      scopedSlots: _vm._u([{
        key: "reference",
        fn: function fn() {
          return [_c("div", {
            staticClass: "tiny-calendar__input"
          }, [_c("input", {
            attrs: {
              "type": "text",
              "readonly": ""
            },
            domProps: {
              "value": _vm.t("ui.datepicker.month" + _vm.state.activeMonth)
            }
          }), _c("div", {
            staticClass: "tiny-calendar__input-btn"
          }, [_c(_vm.state.showYear ? "icon-chevron-up" : "icon-chevron-down", {
            tag: "component",
            staticClass: "tiny-svg-size"
          })], 1)])];
        },
        proxy: true
      }, {
        key: "default",
        fn: function fn() {
          return [_c("div", {
            staticClass: "tiny-calendar__selector"
          }, [_c("ul", {
            staticClass: "tiny-calendar__poplist"
          }, _vm._l(12, function(month) {
            return _c("li", {
              key: month,
              class: ["tiny-calendar__list-item", {
                "is-selected": _vm.state.activeMonth === month
              }],
              attrs: {
                "title": _vm.t("ui.datepicker.month" + month)
              },
              on: {
                "click": function click() {
                  _vm.state.activeMonth = month;
                  _vm.state.showMonth = false;
                }
              }
            }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.month" + month)) + " ")]);
          }), 0)])];
        },
        proxy: true
      }]),
      model: {
        value: _vm.state.showMonth,
        callback: function callback($$v) {
          _vm.$set(_vm.state, "showMonth", $$v);
        },
        expression: "state.showMonth"
      }
    })], 1), _c("li", [_c("Button", {
      attrs: {
        "type": "primary"
      },
      on: {
        "click": _vm.toToday
      }
    }, [_vm._v(_vm._s(_vm.state.displayMode === "month" ? _vm.t("ui.datepicker.today") : _vm.t("ui.datepicker.currentMonth")))])], 1), _c("li", [_c("ul", {
      staticClass: "tiny-calendar__tabs"
    }, [_c("li", {
      class: {
        active: _vm.state.displayMode === "month"
      },
      on: {
        "click": function click($event) {
          return _vm.toggeModel("month");
        }
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.month")) + " ")]), _c("li", {
      class: {
        active: _vm.state.displayMode === "year"
      },
      on: {
        "click": function click($event) {
          return _vm.toggeModel("year");
        }
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.calendar.showType.year")) + " ")])])])])];
  }, {
    "slotScope": _vm.state
  })], 2), _c("div", {
    class: ["tiny-calendar__main", _vm.state.displayMode]
  }, [_c("table", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.displayMode === "month",
      expression: "state.displayMode === 'month'"
    }],
    staticStyle: {
      "table-layout": "fixed"
    }
  }, [_c("tr", [_c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.sun")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.mon")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.tue")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.wed")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.thu")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.fri")))]), _c("th", [_vm._v(_vm._s(_vm.t("ui.datepicker.weeks.sat")))])]), _vm._l(_vm.state.calendar, function(item, index) {
    return _c("tr", {
      key: index
    }, _vm._l(item, function(day, i) {
      return _c("td", {
        key: i,
        attrs: {
          "width": "14.2857%"
        },
        on: {
          "click": function click($event) {
            return _vm.selectDay(day);
          }
        }
      }, [_c("div", {
        class: ["tiny-calendar__day", {
          selected: !(day.isLast || day.isNext) && _vm.state.selectedDate === _vm.getTime(day.value),
          disable: day.isLast || day.isNext,
          today: _vm.isToday(day)
        }]
      }, [_c("div", {
        staticClass: "label"
      }, [_vm._v(_vm._s(day.value))]), !(day.isLast || day.isNext) ? _c("ul", {
        staticClass: "tiny-calendar__events tiny-min-scrollbar"
      }, _vm._l(_vm.getEventByDay(day.value), function(_ref, j) {
        var type = _ref.type, title = _ref.title, content = _ref.content, _ref$parseTime = _ref.parseTime, year = _ref$parseTime.year, month = _ref$parseTime.month, day2 = _ref$parseTime.day, hours = _ref$parseTime.hours, minutes = _ref$parseTime.minutes;
        return _c("li", {
          key: j
        }, [_vm._t("day", function() {
          return [_c("tooltip", {
            staticClass: "tiny-calendar__tip",
            attrs: {
              "type": type,
              "placement": "right",
              "popper-class": "tiny-calendar__tip",
              "mode": "hover"
            },
            scopedSlots: _vm._u([{
              key: "content",
              fn: function fn() {
                return [_c("div", [_c("div", {
                  staticClass: "tiny-calendar__tip-header"
                }, [_c("div", {
                  staticClass: "tiny-calendar__tip-year"
                }, [_vm._v(" " + _vm._s(year + "-" + month + "-" + day2) + " ")]), _c("div", {
                  staticClass: "tiny-calendar__tip-hours"
                }, [_vm._v(" " + _vm._s(hours + ":" + minutes) + " ")])]), _c("div", {
                  class: ["tiny-calendar__tip-title", type || "info"]
                }, [_vm._v(" " + _vm._s(title) + " ")]), _c("div", {
                  staticClass: "tiny-calendar__tip-content"
                }, [_vm._v(" " + _vm._s(content) + " ")])])];
              },
              proxy: true
            }], null, true)
          }, [_c("div", {
            class: ["event", type || "info"]
          }, [_vm._v(_vm._s(title))])])];
        }, {
          "slotScope": {
            type,
            title,
            content,
            year,
            month,
            day: day2,
            hours,
            minutes
          }
        })], 2);
      }), 0) : _vm._e()])]);
    }), 0);
  })], 2), _c("table", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.displayMode === "year",
      expression: "state.displayMode === 'year'"
    }],
    staticStyle: {
      "table-layout": "fixed"
    }
  }, _vm._l(_vm.genMonths(), function(item, i) {
    return _c("tr", {
      key: i
    }, _vm._l(item, function(mth, j) {
      return _c("td", {
        key: j,
        attrs: {
          "width": "25%"
        },
        on: {
          "click": function click($event) {
            return _vm.selectMonth(mth);
          }
        }
      }, [_c("div", {
        class: ["tiny-calendar__day", {
          selected: _vm.state.activeMonth === mth,
          "this-month": _vm.isThisMonth(mth)
        }]
      }, [_c("div", {
        staticClass: "label"
      }, [_vm._v(_vm._s(_vm.t("ui.datepicker.month" + mth)))]), _c("ul", {
        staticClass: "tiny-calendar__events tiny-min-scrollbar"
      }, _vm._l(_vm.getEventByMonth(mth), function(_ref2, k) {
        var type = _ref2.type, title = _ref2.title, content = _ref2.content, _ref2$parseTime = _ref2.parseTime, year = _ref2$parseTime.year, month = _ref2$parseTime.month, day = _ref2$parseTime.day, hours = _ref2$parseTime.hours, minutes = _ref2$parseTime.minutes;
        return _c("li", {
          key: k
        }, [_vm._t("month", function() {
          return [_c("tooltip", {
            staticClass: "tiny-calendar__tip",
            attrs: {
              "type": type,
              "placement": "right",
              "popper-class": "tiny-calendar__tip",
              "mode": "hover"
            },
            scopedSlots: _vm._u([{
              key: "content",
              fn: function fn() {
                return [_c("div", [_c("div", {
                  staticClass: "tiny-calendar__tip-header"
                }, [_c("div", {
                  staticClass: "tiny-calendar__tip-year"
                }, [_vm._v(" " + _vm._s(year + "-" + month + "-" + day) + " ")]), _c("div", {
                  staticClass: "tiny-calendar__tip-hours"
                }, [_vm._v(" " + _vm._s(hours + ":" + minutes) + " ")])]), _c("div", {
                  class: ["tiny-calendar__tip-title", type || "info"]
                }, [_vm._v(" " + _vm._s(title) + " ")]), _c("div", {
                  staticClass: "tiny-calendar__tip-content"
                }, [_vm._v(" " + _vm._s(content) + " ")])])];
              },
              proxy: true
            }], null, true)
          }, [_c("div", {
            class: ["event", type || "info"]
          }, [_vm._v(_vm._s(title))])])];
        }, {
          "slotScope": {
            type,
            title,
            content,
            year,
            month,
            day,
            hours,
            minutes
          }
        })], 2);
      }), 0)])]);
    }), 0);
  }), 0)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
